]> granicus.if.org Git - neomutt/commitdiff
rename mbyte functions
authorRichard Russon <rich@flatcap.org>
Thu, 16 Nov 2017 02:30:25 +0000 (02:30 +0000)
committerRichard Russon <rich@flatcap.org>
Thu, 16 Nov 2017 03:39:56 +0000 (03:39 +0000)
enter.c
hdrline.c
mutt/mbyte.c
mutt/mbyte.h
muttlib.c
sendlib.c

diff --git a/enter.c b/enter.c
index 780fc0b14f39edb48ccefe47f6ac775f7bb18dd4..c5ff00cd2c886204ce6d328783d7532d85369275 100644 (file)
--- a/enter.c
+++ b/enter.c
@@ -81,7 +81,7 @@ static void replace_part(struct EnterState *state, size_t from, char *buf)
   }
 
   /* Convert to wide characters */
-  state->curpos = my_mbstowcs(&state->wbuf, &state->wbuflen, from, buf);
+  state->curpos = mutt_mb_mbstowcs(&state->wbuf, &state->wbuflen, from, buf);
 
   if (savelen)
   {
@@ -176,7 +176,7 @@ int mutt_enter_string_full(char *buf, size_t buflen, int col, int flags, int mul
   {
     /* Initialise wbuf from buf */
     state->wbuflen = 0;
-    state->lastchar = my_mbstowcs(&state->wbuf, &state->wbuflen, 0, buf);
+    state->lastchar = mutt_mb_mbstowcs(&state->wbuf, &state->wbuflen, 0, buf);
     redraw = MUTT_REDRAW_INIT;
   }
 
@@ -204,25 +204,25 @@ int mutt_enter_string_full(char *buf, size_t buflen, int col, int flags, int mul
         /* Go to end of line */
         state->curpos = state->lastchar;
         state->begin =
-            width_ceiling(state->wbuf, state->lastchar,
-                          my_wcswidth(state->wbuf, state->lastchar) - width + 1);
+            mutt_mb_width_ceiling(state->wbuf, state->lastchar,
+                          mutt_mb_wcswidth(state->wbuf, state->lastchar) - width + 1);
       }
       if (state->curpos < state->begin ||
-          my_wcswidth(state->wbuf + state->begin, state->curpos - state->begin) >= width)
-        state->begin = width_ceiling(state->wbuf, state->lastchar,
-                                     my_wcswidth(state->wbuf, state->curpos) - width / 2);
+          mutt_mb_wcswidth(state->wbuf + state->begin, state->curpos - state->begin) >= width)
+        state->begin = mutt_mb_width_ceiling(state->wbuf, state->lastchar,
+                                     mutt_mb_wcswidth(state->wbuf, state->curpos) - width / 2);
       mutt_window_move(MuttMessageWindow, 0, col);
       w = 0;
       for (i = state->begin; i < state->lastchar; i++)
       {
-        w += my_wcwidth(state->wbuf[i]);
+        w += mutt_mb_wcwidth(state->wbuf[i]);
         if (w > width)
           break;
         my_addwch(state->wbuf[i]);
       }
       mutt_window_clrtoeol(MuttMessageWindow);
       mutt_window_move(MuttMessageWindow, 0,
-                       col + my_wcswidth(state->wbuf + state->begin,
+                       col + mutt_mb_wcswidth(state->wbuf + state->begin,
                                          state->curpos - state->begin));
     }
     mutt_refresh();
@@ -246,7 +246,7 @@ int mutt_enter_string_full(char *buf, size_t buflen, int col, int flags, int mul
           state->curpos = state->lastchar;
           if (mutt_history_at_scratch(hclass))
           {
-            my_wcstombs(buf, buflen, state->wbuf, state->curpos);
+            mutt_mb_wcstombs(buf, buflen, state->wbuf, state->curpos);
             mutt_history_save_scratch(hclass, buf);
           }
           replace_part(state, 0, mutt_history_prev(hclass));
@@ -257,7 +257,7 @@ int mutt_enter_string_full(char *buf, size_t buflen, int col, int flags, int mul
           state->curpos = state->lastchar;
           if (mutt_history_at_scratch(hclass))
           {
-            my_wcstombs(buf, buflen, state->wbuf, state->curpos);
+            mutt_mb_wcstombs(buf, buflen, state->wbuf, state->curpos);
             mutt_history_save_scratch(hclass, buf);
           }
           replace_part(state, 0, mutt_history_next(hclass));
@@ -447,10 +447,10 @@ int mutt_enter_string_full(char *buf, size_t buflen, int col, int flags, int mul
           if (flags & MUTT_EFILE)
           {
             first = 1; /* clear input if user types a real key later */
-            my_wcstombs(buf, buflen, state->wbuf, state->curpos);
+            mutt_mb_wcstombs(buf, buflen, state->wbuf, state->curpos);
             mutt_buffy(buf, buflen);
             state->curpos = state->lastchar =
-                my_mbstowcs(&state->wbuf, &state->wbuflen, 0, buf);
+                mutt_mb_mbstowcs(&state->wbuf, &state->wbuflen, 0, buf);
             break;
           }
           else if (!(flags & MUTT_FILE))
@@ -462,9 +462,9 @@ int mutt_enter_string_full(char *buf, size_t buflen, int col, int flags, int mul
           state->tabs++;
           if (flags & MUTT_CMD)
           {
-            for (i = state->curpos; i && !is_shell_char(state->wbuf[i - 1]); i--)
+            for (i = state->curpos; i && !mutt_mb_is_shell_char(state->wbuf[i - 1]); i--)
               ;
-            my_wcstombs(buf, buflen, state->wbuf + i, state->curpos - i);
+            mutt_mb_wcstombs(buf, buflen, state->wbuf + i, state->curpos - i);
             if (tempbuf && templen == state->lastchar - i &&
                 !memcmp(tempbuf, state->wbuf + i, (state->lastchar - i) * sizeof(wchar_t)))
             {
@@ -493,7 +493,7 @@ int mutt_enter_string_full(char *buf, size_t buflen, int col, int flags, int mul
               ;
             for (; i < state->lastchar && state->wbuf[i] == ' '; i++)
               ;
-            my_wcstombs(buf, buflen, state->wbuf + i, state->curpos - i);
+            mutt_mb_wcstombs(buf, buflen, state->wbuf + i, state->curpos - i);
             r = mutt_alias_complete(buf, buflen);
             replace_part(state, i, buf);
             if (!r)
@@ -510,7 +510,7 @@ int mutt_enter_string_full(char *buf, size_t buflen, int col, int flags, int mul
               ;
             for (; i < state->lastchar && state->wbuf[i] == ' '; i++)
               ;
-            my_wcstombs(buf, buflen, state->wbuf + i, state->curpos - i);
+            mutt_mb_wcstombs(buf, buflen, state->wbuf + i, state->curpos - i);
             r = mutt_label_complete(buf, buflen, state->tabs);
             replace_part(state, i, buf);
             if (!r)
@@ -527,7 +527,7 @@ int mutt_enter_string_full(char *buf, size_t buflen, int col, int flags, int mul
             if (i && i < state->curpos && state->wbuf[i - 1] == '~' && state->wbuf[i] == 'y')
             {
               i++;
-              my_wcstombs(buf, buflen, state->wbuf + i, state->curpos - i);
+              mutt_mb_wcstombs(buf, buflen, state->wbuf + i, state->curpos - i);
               r = mutt_label_complete(buf, buflen, state->tabs);
               replace_part(state, i, buf);
               if (!r)
@@ -550,7 +550,7 @@ int mutt_enter_string_full(char *buf, size_t buflen, int col, int flags, int mul
                 ;
             }
 
-            my_wcstombs(buf, buflen, state->wbuf + i, state->curpos - i);
+            mutt_mb_wcstombs(buf, buflen, state->wbuf + i, state->curpos - i);
             mutt_query_complete(buf, buflen);
             replace_part(state, i, buf);
 
@@ -559,7 +559,7 @@ int mutt_enter_string_full(char *buf, size_t buflen, int col, int flags, int mul
           }
           else if (flags & MUTT_COMMAND)
           {
-            my_wcstombs(buf, buflen, state->wbuf, state->curpos);
+            mutt_mb_wcstombs(buf, buflen, state->wbuf, state->curpos);
             i = strlen(buf);
             if (i && buf[i - 1] == '=' && mutt_var_value_complete(buf, buflen, i))
               state->tabs = 0;
@@ -569,7 +569,7 @@ int mutt_enter_string_full(char *buf, size_t buflen, int col, int flags, int mul
           }
           else if (flags & (MUTT_FILE | MUTT_EFILE))
           {
-            my_wcstombs(buf, buflen, state->wbuf, state->curpos);
+            mutt_mb_wcstombs(buf, buflen, state->wbuf, state->curpos);
 
             /* see if the path has changed from the last time */
             if ((!tempbuf && !state->lastchar) ||
@@ -607,7 +607,7 @@ int mutt_enter_string_full(char *buf, size_t buflen, int col, int flags, int mul
 #ifdef USE_NOTMUCH
           else if (flags & MUTT_NM_QUERY)
           {
-            my_wcstombs(buf, buflen, state->wbuf, state->curpos);
+            mutt_mb_wcstombs(buf, buflen, state->wbuf, state->curpos);
             i = strlen(buf);
             if (!mutt_nm_query_complete(buf, buflen, i, state->tabs))
               BEEP();
@@ -616,7 +616,7 @@ int mutt_enter_string_full(char *buf, size_t buflen, int col, int flags, int mul
           }
           else if (flags & MUTT_NM_TAG)
           {
-            my_wcstombs(buf, buflen, state->wbuf, state->curpos);
+            mutt_mb_wcstombs(buf, buflen, state->wbuf, state->curpos);
             i = strlen(buf);
             if (!mutt_nm_tag_complete(buf, buflen, i, state->tabs))
               BEEP();
@@ -701,7 +701,7 @@ int mutt_enter_string_full(char *buf, size_t buflen, int col, int flags, int mul
       if (wc == '\r' || wc == '\n')
       {
         /* Convert from wide characters */
-        my_wcstombs(buf, buflen, state->wbuf, state->lastchar);
+        mutt_mb_wcstombs(buf, buflen, state->wbuf, state->lastchar);
         if (!pass)
           mutt_history_add(hclass, buf, true);
 
index 0b7cadc825dea29aad1b1b78dcf2b48a6b26b031..74281fc0d2c875df9d8864ca66dc64c043877990 100644 (file)
--- a/muttlib.c
+++ b/muttlib.c
@@ -1204,7 +1204,7 @@ void mutt_expando_format(char *dest, size_t destlen, size_t col, int cols,
          * %*X: right justify to EOL, right takes precedence */
         int soft = ch == '*';
         int pl, pw;
-        pl = mutt_charlen(src, &pw);
+        pl = mutt_mb_charlen(src, &pw);
         if (pl <= 0)
           pl = pw = 1;
 
@@ -1279,7 +1279,7 @@ void mutt_expando_format(char *dest, size_t destlen, size_t col, int cols,
       {
         /* pad to EOL */
         int pl, pw, c;
-        pl = mutt_charlen(src, &pw);
+        pl = mutt_mb_charlen(src, &pw);
         if (pl <= 0)
           pl = pw = 1;
 
@@ -1373,7 +1373,7 @@ void mutt_expando_format(char *dest, size_t destlen, size_t col, int cols,
     {
       int tmp, w;
       /* in case of error, simply copy byte */
-      tmp = mutt_charlen(src, &w);
+      tmp = mutt_mb_charlen(src, &w);
       if (tmp < 0)
         tmp = w = 1;
       if (tmp > 0 && wlen + tmp < destlen)
index eec383cdf8711455320c1e6e85c77b2f8c397030..aa7a904fff460f7396837d15eee1c493a5164dd6 100644 (file)
--- a/sendlib.c
+++ b/sendlib.c
@@ -1741,7 +1741,7 @@ static int fold_one_header(FILE *fp, const char *tag, const char *value,
 
     /* determine width: character cells for display, bytes for sending
      * (we get pure ascii only) */
-    w = my_width(buf, col, display);
+    w = mutt_mb_width(buf, col, display);
     enc = (mutt_strncmp(buf, "=?", 2) == 0);
 
     mutt_debug(5, "mwoh: word=[%s], col=%d, w=%d, next=[0x0%x]\n", buf, col, w, *next);
@@ -1967,7 +1967,7 @@ int mutt_write_one_header(FILE *fp, const char *tag, const char *value,
     /* find maximum line width in current header */
     if (p)
       *p = 0;
-    w = my_width(line, 0, display);
+    w = mutt_mb_width(line, 0, display);
     if (w > max)
       max = w;
     if (p)
--- a/hdrline.c
+++ b/hdrline.c
@@ -496,7 +496,7 @@ static const char *hdr_format_str(char *dest, size_t destlen, size_t col, int co
       }
       else
       {
-        if (get_initials(mutt_get_name(hdr->env->from), buf2, sizeof(buf2)))
+        if (mutt_mb_get_initials(mutt_get_name(hdr->env->from), buf2, sizeof(buf2)))
         {
           colorlen = add_index_color(dest, destlen, flags, MT_COLOR_INDEX_AUTHOR);
           mutt_format_s(dest + colorlen, destlen - colorlen, prefix, buf2);
index 8ab7c4a1a28181c8a0408fb837ec17d7380dd424..66ed7d8aa5605c4f80651fdf92846df09545d8c1 100644 (file)
  * | :--------------- | :--------------------------------------------------
  * | #ReplacementChar | When a Unicode character can't be displayed, use this instead
  *
* | Function        | Description
* | :-------------- | :---------------------------------------------------------
* | get_initials()  | Turn a name into initials
* | is_shell_char() | Is character not typically part of a pathname
* | mutt_charlen()  | Count the bytes in a (multibyte) character
* | my_mbstowcs()   | Convert a string from multibyte to wide characters
* | my_wcstombs()   | Convert a string from wide to multibyte characters
* | my_wcswidth()   | Measure the screen width of a string
* | my_wcwidth()    | Measure the screen width of a character
* | my_width()      | Measure a string's display width (in screen columns)
* | width_ceiling() | Keep the end of the string on-screen
  */
 
 #include "config.h"
@@ -62,7 +62,7 @@ bool OPT_LOCALES; /**< (pseudo) set if user has valid locale definition */
 wchar_t ReplacementChar = '?';
 
 /**
* mutt_charlen - Count the bytes in a (multibyte) character
  * @param[in]  s     String to be examined
  * @param[out] width Number of screen columns the character would use
  * @retval n  Number of bytes in the first (multibyte) character of input consumes
@@ -70,7 +70,7 @@ wchar_t ReplacementChar = '?';
  * @retval =0 End of input
  * @retval >0 Length (bytes)
  */
-int mutt_charlen(const char *s, int *width)
+int mutt_mb_charlen(const char *s, int *width)
 {
   wchar_t wc;
   mbstate_t mbstate;
@@ -88,7 +88,7 @@ int mutt_charlen(const char *s, int *width)
 }
 
 /**
* get_initials - Turn a name into initials
  * @param name   String to be converted
  * @param buf    Buffer for the result
  * @param buflen Size of the buffer
@@ -99,7 +99,7 @@ int mutt_charlen(const char *s, int *width)
  * The function saves the first character from each word.  Words are delimited
  * by whitespace, or hyphens (so "Jean-Pierre" becomes "JP").
  */
-bool get_initials(const char *name, char *buf, int buflen)
+bool mutt_mb_get_initials(const char *name, char *buf, int buflen)
 {
   if (!name || !buf)
     return false;
@@ -107,7 +107,7 @@ bool get_initials(const char *name, char *buf, int buflen)
   while (*name)
   {
     /* Char's length in bytes */
-    int clen = mutt_charlen(name, NULL);
+    int clen = mutt_mb_charlen(name, NULL);
     if (clen < 1)
       return false;
 
@@ -129,7 +129,7 @@ bool get_initials(const char *name, char *buf, int buflen)
     /* Skip to end-of-word */
     for (; *name; name += clen)
     {
-      clen = mutt_charlen(name, NULL);
+      clen = mutt_mb_charlen(name, NULL);
       if (clen < 1)
         return false;
       else if ((clen == 1) && (isspace(*name) || (*name == '-')))
@@ -146,7 +146,7 @@ bool get_initials(const char *name, char *buf, int buflen)
 }
 
 /**
* my_width - Measure a string's display width (in screen columns)
  * @param str     String to measure
  * @param col     Display column (used for expanding tabs)
  * @param display will this be displayed to the user?
@@ -154,7 +154,7 @@ bool get_initials(const char *name, char *buf, int buflen)
  *
  * This is like wcwidth(), but gets const char* not wchar_t*.
  */
-int my_width(const char *str, int col, bool display)
+int mutt_mb_width(const char *str, int col, bool display)
 {
   wchar_t wc;
   int l, w = 0, nl = 0;
@@ -189,11 +189,11 @@ int my_width(const char *str, int col, bool display)
 }
 
 /**
* my_wcwidth - Measure the screen width of a character
  * @param wc Character to examine
  * @retval int Width in screen columns
  */
-int my_wcwidth(wchar_t wc)
+int mutt_mb_wcwidth(wchar_t wc)
 {
   int n = wcwidth(wc);
   if (IsWPrint(wc) && n > 0)
@@ -206,21 +206,21 @@ int my_wcwidth(wchar_t wc)
 }
 
 /**
* my_wcswidth - Measure the screen width of a string
  * @param s String to measure
  * @param n Length of string in characters
  * @retval int Width in screen columns
  */
-int my_wcswidth(const wchar_t *s, size_t n)
+int mutt_mb_wcswidth(const wchar_t *s, size_t n)
 {
   int w = 0;
   while (n--)
-    w += my_wcwidth(*s++);
+    w += mutt_mb_wcwidth(*s++);
   return w;
 }
 
 /**
* width_ceiling - Keep the end of the string on-screen
  * @param s String being displayed
  * @param n Length of string in characters
  * @param w1 Width limit
@@ -229,24 +229,24 @@ int my_wcswidth(const wchar_t *s, size_t n)
  * Given a string and a width, determine how many characters from the
  * beginning of the string should be skipped so that the string fits.
  */
-size_t width_ceiling(const wchar_t *s, size_t n, int w1)
+size_t mutt_mb_width_ceiling(const wchar_t *s, size_t n, int w1)
 {
   const wchar_t *s0 = s;
   int w = 0;
   for (; n; s++, n--)
-    if ((w += my_wcwidth(*s)) > w1)
+    if ((w += mutt_mb_wcwidth(*s)) > w1)
       break;
   return s - s0;
 }
 
 /**
* my_wcstombs - Convert a string from wide to multibyte characters
  * @param dest Buffer for the result
  * @param dlen Length of the result buffer
  * @param src Source string to convert
  * @param slen Length of the source string
  */
-void my_wcstombs(char *dest, size_t dlen, const wchar_t *src, size_t slen)
+void mutt_mb_wcstombs(char *dest, size_t dlen, const wchar_t *src, size_t slen)
 {
   mbstate_t st;
   size_t k;
@@ -288,14 +288,14 @@ void my_wcstombs(char *dest, size_t dlen, const wchar_t *src, size_t slen)
 }
 
 /**
* my_mbstowcs - Convert a string from multibyte to wide characters
  * @param pwbuf    Buffer for the result
  * @param pwbuflen Length of the result buffer
  * @param i        Starting index into the result buffer
  * @param buf      String to convert
  * @retval size_t First character after the result
  */
-size_t my_mbstowcs(wchar_t **pwbuf, size_t *pwbuflen, size_t i, char *buf)
+size_t mutt_mb_mbstowcs(wchar_t **pwbuf, size_t *pwbuflen, size_t i, char *buf)
 {
   wchar_t wc;
   mbstate_t st;
@@ -337,14 +337,14 @@ size_t my_mbstowcs(wchar_t **pwbuf, size_t *pwbuflen, size_t i, char *buf)
 }
 
 /**
* is_shell_char - Is character not typically part of a pathname
  * @param ch Character to examine
  * @retval true  Character is not typically part of a pathname
  * @retval false Character is typically part of a pathname
  *
  * @note The name is very confusing.
  */
-bool is_shell_char(wchar_t ch)
+bool mutt_mb_is_shell_char(wchar_t ch)
 {
   static const wchar_t shell_chars[] = L"<>&()$?*;{}| "; /* ! not included because it can be part of a pathname in NeoMutt */
   return wcschr(shell_chars, ch) != NULL;
index 5c710430333374a559acd5cbb83501b3027e086f..fad6d6d15dbdbebe85a8dac24e3b22559f0dab57 100644 (file)
@@ -41,14 +41,14 @@ extern wchar_t ReplacementChar;
 #define IsWPrint(wc) (iswprint(wc) || (OPT_LOCALES ? 0 : (wc >= 0xa0)))
 #endif
 
-bool   get_initials(const char *name, char *buf, int buflen);
-bool   is_shell_char(wchar_t ch);
-int    mutt_charlen(const char *s, int *width);
-size_t my_mbstowcs(wchar_t **pwbuf, size_t *pwbuflen, size_t i, char *buf);
-void   my_wcstombs(char *dest, size_t dlen, const wchar_t *src, size_t slen);
-int    my_wcswidth(const wchar_t *s, size_t n);
-int    my_wcwidth(wchar_t wc);
-int    my_width(const char *str, int col, bool display);
-size_t width_ceiling(const wchar_t *s, size_t n, int w1);
+int    mutt_mb_charlen(const char *s, int *width);
+bool   mutt_mb_get_initials(const char *name, char *buf, int buflen);
+bool   mutt_mb_is_shell_char(wchar_t ch);
+size_t mutt_mb_mbstowcs(wchar_t **pwbuf, size_t *pwbuflen, size_t i, char *buf);
+void   mutt_mb_wcstombs(char *dest, size_t dlen, const wchar_t *src, size_t slen);
+int    mutt_mb_wcswidth(const wchar_t *s, size_t n);
+int    mutt_mb_wcwidth(wchar_t wc);
+size_t mutt_mb_width_ceiling(const wchar_t *s, size_t n, int w1);
+int    mutt_mb_width(const char *str, int col, bool display);
 
 #endif /* _MUTT_MBYTE_H */
index 7096822b3abb58e69910bd88d37cfbf9f52cec9e..e40198c5e63f743540c0a3a537c60602d4afeaba 100644 (file)
@@ -496,7 +496,7 @@ static const char *hdr_format_str(char *dest, size_t destlen, size_t col, int co
  * | #ReplacementChar | When a Unicode character can't be displayed, use this instead
  *
- * | Function        | Description
- * | :-------------- | :---------------------------------------------------------
- * | get_initials()  | Turn a name into initials
- * | is_shell_char() | Is character not typically part of a pathname
- * | mutt_charlen()  | Count the bytes in a (multibyte) character
- * | my_mbstowcs()   | Convert a string from multibyte to wide characters
- * | my_wcstombs()   | Convert a string from wide to multibyte characters
- * | my_wcswidth()   | Measure the screen width of a string
- * | my_wcwidth()    | Measure the screen width of a character
- * | my_width()      | Measure a string's display width (in screen columns)
- * | width_ceiling() | Keep the end of the string on-screen
+ * | Function                | Description
+ * | :---------------------- | :---------------------------------------------------------
+ * | mutt_mb_charlen()       | Count the bytes in a (multibyte) character
+ * | mutt_mb_get_initials()  | Turn a name into initials
+ * | mutt_mb_is_shell_char() | Is character not typically part of a pathname
+ * | mutt_mb_mbstowcs()      | Convert a string from multibyte to wide characters
+ * | mutt_mb_wcstombs()      | Convert a string from wide to multibyte characters
+ * | mutt_mb_wcswidth()      | Measure the screen width of a string
+ * | mutt_mb_wcwidth()       | Measure the screen width of a character
+ * | mutt_mb_width()         | Measure a string's display width (in screen columns)
+ * | mutt_mb_width_ceiling() | Keep the end of the string on-screen
  */
 
@@ -62,7 +62,7 @@ bool OPT_LOCALES; /**< (pseudo) set if user has valid locale definition */
 
 /**
- * mutt_charlen - Count the bytes in a (multibyte) character
+ * mutt_mb_charlen - Count the bytes in a (multibyte) character
  * @param[in]  s     String to be examined
  * @param[out] width Number of screen columns the character would use
@@ -88,7 +88,7 @@ int mutt_charlen(const char *s, int *width)
 
 /**
- * get_initials - Turn a name into initials
+ * mutt_mb_get_initials - Turn a name into initials
  * @param name   String to be converted
  * @param buf    Buffer for the result
@@ -146,7 +146,7 @@ bool get_initials(const char *name, char *buf, int buflen)
 
 /**
- * my_width - Measure a string's display width (in screen columns)
+ * mutt_mb_width - Measure a string's display width (in screen columns)
  * @param str     String to measure
  * @param col     Display column (used for expanding tabs)
@@ -189,11 +189,11 @@ int my_width(const char *str, int col, bool display)
 
 /**
- * my_wcwidth - Measure the screen width of a character
+ * mutt_mb_wcwidth - Measure the screen width of a character
  * @param wc Character to examine
  * @retval int Width in screen columns
@@ -206,21 +206,21 @@ int my_wcwidth(wchar_t wc)
 
 /**
- * my_wcswidth - Measure the screen width of a string
+ * mutt_mb_wcswidth - Measure the screen width of a string
  * @param s String to measure
  * @param n Length of string in characters
@@ -206,21 +206,21 @@ int my_wcwidth(wchar_t wc)
 
 /**
- * width_ceiling - Keep the end of the string on-screen
+ * mutt_mb_width_ceiling - Keep the end of the string on-screen
  * @param s String being displayed
  * @param n Length of string in characters
@@ -229,24 +229,24 @@ int my_wcswidth(const wchar_t *s, size_t n)
 
 /**
- * my_wcstombs - Convert a string from wide to multibyte characters
+ * mutt_mb_wcstombs - Convert a string from wide to multibyte characters
  * @param dest Buffer for the result
  * @param dlen Length of the result buffer
@@ -288,14 +288,14 @@ void my_wcstombs(char *dest, size_t dlen, const wchar_t *src, size_t slen)
 
 /**
- * my_mbstowcs - Convert a string from multibyte to wide characters
+ * mutt_mb_mbstowcs - Convert a string from multibyte to wide characters
  * @param pwbuf    Buffer for the result
  * @param pwbuflen Length of the result buffer
@@ -337,14 +337,14 @@ size_t my_mbstowcs(wchar_t **pwbuf, size_t *pwbuflen, size_t i, char *buf)
 
 /**
- * is_shell_char - Is character not typically part of a pathname
+ * mutt_mb_is_shell_char - Is character not typically part of a pathname
  * @param ch Character to examine
  * @retval true  Character is not typically part of a pathname